@@ -24,14 +24,6 @@ impl Param {
         self.attributes().any(|attribute| attribute.name() == name)
     }
 
-    pub fn is_input(&self) -> bool {
-        self.flags().input()
-    }
-
-    pub fn is_optional(&self) -> bool {
-        self.flags().optional()
-    }
-
     pub fn is_com_out_ptr(&self) -> bool {
         self.has_attribute("ComOutPtrAttribute")
     }
@@ -40,4 +32,8 @@ impl Param {
         // TODO: replace bool return with actual array info from attribute
         self.has_attribute("NativeArrayInfoAttribute")
     }
+
+    pub fn is_retval(&self) -> bool {
+        self.has_attribute("RetValAttribute")
+    }
 }
